"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments)).next());
    });
};
const kendoui_base_1 = require("./kendoui-base");
class KendoUINotesCommand extends kendoui_base_1.KendoUIBaseCommand {
    constructor($logger, $opener, $prompter, $errors, $kendoUIService, $loginManager, $options, $project) {
        super($errors, $project, $kendoUIService, $loginManager, $options);
        this.$logger = $logger;
        this.$opener = $opener;
        this.$prompter = $prompter;
        this.allowedParameters = [];
    }
    execute(args) {
        return __awaiter(this, void 0, void 0, function* () {
            let packages = yield this.getKendoPackages({ withReleaseNotesOnly: true });
            if (packages.length === 1) {
                this.$opener.open(_.first(packages).ReleaseNotesUrl);
                return;
            }
            this.$logger.out("You can review release notes for the following Kendo UI packages.");
            this.$logger.out(this.getKendoPackagesAsTable(packages));
            let schema = {
                type: "input",
                name: "packageIdx",
                message: "Enter the index of the package",
                validate: (value) => {
                    let num = parseInt(value, 10);
                    return !isNaN(num) && num >= 1 && num <= packages.length ? true : `Valid values are between 1 and ${packages.length}.`;
                }
            };
            let choice = yield this.$prompter.get([schema]);
            let selectedPackage = packages[parseInt(choice.packageIdx) - 1];
            this.$opener.open(selectedPackage.ReleaseNotesUrl);
        });
    }
}
$injector.registerCommand("kendoui|notes", KendoUINotesCommand);
